==> haskell-charset-0.3.7.1-16-i686.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-3a0NuAdu11f19u3FDKNoMz
key: charset-0.3.7.1-3a0NuAdu11f19u3FDKNoMz
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
abi: cd39f9363f446c1f2625ee32b9d68731
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-3a0NuAdu11f19u3FDKNoMz
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.7.1-17-i686.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-K8TwicOajUdHmq8r06VVim
key: charset-0.3.7.1-K8TwicOajUdHmq8r06VVim
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
abi: 0052b6f2fd059f1a09c277e714cf7200
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-K8TwicOajUdHmq8r06VVim
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
